@@ -30,7 +30,7 @@ class ARF(ScatteringField, BaseARF, BaseSphereFrequencyComposite):
        thickness is implemented.
 
        Both values will be logged in the `info.log` when calling
-       :meth:`acoustic_radiation_force`. These conditions will not be
+       :meth:`compute_arf()`. These conditions will not be
        checked at runtime.
 
 
@@ -268,7 +268,7 @@ class ARF(ScatteringField, BaseARF, BaseSphereFrequencyComposite):
     # API
     # -------------------------------------------------------------------------
 
-    def acoustic_radiation_force(self) -> float:
+    def compute_arf(self) -> float:
         """Acoustic radiation fore in [N]
 
         It logs the current values of :attr:`x` and :attr:`x_v`.
@@ -417,6 +417,8 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
 
     @property
     def eta_t(self):
+        """By fluid normalized dynamic viscosity
+        """
         return self._eta_t.value
 
     def _compute_eta_t(self):
@@ -424,6 +426,8 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
 
     @property
     def zeta_t(self):
+        """By fluid normalized bulk viscosity
+        """
         return self._zeta_t.value
 
     def _compute_zeta_t(self):
@@ -431,6 +435,8 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
 
     @property
     def f1(self):
+        """f1 factor of Appendix B
+        """
         return self._f1.value
 
     def _compute_f1(self):
@@ -438,6 +444,8 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
 
     @property
     def f2(self):
+        """f2 factor of Appendix B
+        """
         return self._f2.value
 
     def _compute_f2(self):
@@ -447,6 +455,8 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
 
     @property
     def f3(self):
+        """f3 factor of Appendix B
+        """
         return self._f3.value
 
     def _compute_f3(self):
@@ -454,6 +464,8 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
 
     @property
     def f4(self):
+        """f4 factor of Appendix B
+        """
         return self._f4.value
 
     def _compute_f4(self):
@@ -461,6 +473,8 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
 
     @property
     def G(self):
+        """G factor Eq (7.9)
+        """
         return self._G.value
 
     def _compute_G(self):
@@ -468,6 +482,8 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
 
     @property
     def S1(self):
+        """S_1 factor Eq (7.10)
+        """
         return self._S1.value
 
     def _compute_S1(self):
@@ -475,6 +491,8 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
 
     @property
     def S2(self):
+        """S_2 factor Eq (7.11)
+        """
         return self._S2.value
 
     def _compute_S2(self):
@@ -486,6 +504,8 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
 
     @property
     def S3(self):
+        """S_3 factor Eq (7.12)
+        """
         return self._S3.value
 
     def _compute_S3(self):
@@ -501,6 +521,8 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
 
     @property
     def g1(self):
+        """g1 factor of Appendix B
+        """
         return self._g1.value
 
     def _compute_g1(self):
@@ -508,6 +530,8 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
 
     @property
     def g2(self):
+        """g2 factor of Appendix B
+        """
         return self._g2.value
 
     def _compute_g2(self):
@@ -519,6 +543,8 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
 
     @property
     def g3(self):
+        """g3 factor of Appendix B
+        """
         return self._g3.value
 
     def _compute_g3(self):
@@ -530,6 +556,8 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
 
     @property
     def g4(self):
+        """g4 factor of Appendix B
+        """
         return self._g4.value
 
     def _compute_g4(self):
@@ -541,6 +569,8 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
 
     @property
     def g5(self):
+        """g5 factor of Appendix B
+        """
         return self._g5.value
 
     def _compute_g5(self):
@@ -550,6 +580,8 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
 
     @property
     def g6(self):
+        """g6 factor of Appendix B
+        """
         return self._g6.value
 
     def _compute_g6(self):
@@ -557,6 +589,8 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
 
     @property
     def g7(self):
+        """g7 factor of Appendix B
+        """
         return self._g7.value
 
     def _compute_g7(self):
@@ -574,7 +608,8 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
 
     @property
     def mu(self) -> float:
-        """ (density * viscosity) ratio
+        """ (density x viscosity) ratio
+        :math:`\\tilde{\\mu}=\\frac{\\rho_f\\eta_f}{\\rho_s\\eta_s}`
         """
         return self._mu.value
 
@@ -586,6 +621,7 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
     @property
     def kappa_t(self) -> float:
         """ compressibility ratio
+        :math:`\\tilde{\\kappa}=\\frac{\\kappa_s}{\\kappa_f}`
         """
         return self._kappa_t.value
 
