@@ -27,7 +27,7 @@ class ARF(ScatteringField, BaseARF, BaseSphereFrequencyComposite):
        `False` than :math:`|x| \\ll 1 \\ll |x_v|` must hold.
 
        Both values will be logged in the `info.log` when calling
-       :meth:`acoustic_radiation_force`. These conditions will not be
+       :meth:`compute_arf()`. These conditions will not be
        checked at runtime.
 
 
@@ -238,7 +238,7 @@ class ARF(ScatteringField, BaseARF, BaseSphereFrequencyComposite):
     # API
     # -------------------------------------------------------------------------
 
-    def acoustic_radiation_force(self) -> float:
+    def compute_arf(self) -> float:
         """Acoustic radiation fore in [N]
 
         It logs the current values of :attr:`x` and :attr:`x_v`.
@@ -335,7 +335,7 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
             return self._arf_small_particle_standing()
 
     def _arf_small_particle_travelling(self) -> float:
-        """Eq. (5.10), (5.12), (6.1), (6.2)
+        """Eq (5.10), (5.12), (6.1), (6.2)
         """
         # F1
         F1 = self.D_0 - self.D_0.conjugate()
@@ -346,7 +346,7 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
         return (F1 + F2).real
 
     def _arf_small_particle_standing(self) -> float:
-        """Eq. (5.15), (5.16), (6.1), (6.2)
+        """ Eq (5.15), (5.16), (6.1), (6.2)
         """
         # F1
         sine = sin(2 * self.k_f * self.abs_pos)
@@ -427,7 +427,7 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
 
     @property
     def D_0(self) -> complex:
-        """Approximation for the coefficient D_0 from Eq. (6.1)
+        """Approximation for the coefficient D_0 from Eq (6.1)
         """
         return self._D_0.value
 
@@ -441,7 +441,7 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
 
     @property
     def D_1(self) -> complex:
-        """Approximation for the coefficient D_1 from Eq. (6.2)
+        """Approximation for the coefficient D_1 from Eq (6.2)
         """
         return self._D_1.value
 
@@ -471,7 +471,7 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
 
     @property
     def G_0(self) -> complex:
-        """Approximation to value G_0 from Eq. (6.3)
+        """Approximation to value G_0 from Eq (6.3)
         """
         return self._G_0.value
 
@@ -483,7 +483,7 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
 
     @property
     def G_1(self) -> complex:
-        """Approximation to value G_1 from Eq. (6.4)
+        """Approximation to value G_1 from Eq (6.4)
         """
         return self._G_1.value
 
@@ -494,7 +494,7 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
 
     @property
     def G_2(self) -> complex:
-        """Approximation to value G_2 from Eq. (6.5)
+        """Approximation to value G_2 from Eq (6.5)
         """
         return self._G_2.value
 
@@ -511,7 +511,7 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
 
     @property
     def G_3(self) -> complex:
-        """Approximation to value G_3 from Eq. (6.6)
+        """Approximation to value G_3 from Eq (6.6)
         """
         return self._G_3.value
 
@@ -520,7 +520,7 @@ Doinikov1994Rigid.baseclass.aseDoinikov1994Rigid.wave_type`
 
     @property
     def G_4(self) -> complex:
-        """Approximation to value G_4 from Eq. (6.7)
+        """Approximation to value G_4 from Eq (6.7)
         """
         return self._G_4.value
 
