@@ -159,7 +159,7 @@ class TestARFMethods(TestARFBase):
 
         self.assertRaises(
             WrongWaveTypeError,
-            self.cls.acoustic_radiation_force,
+            self.cls.compute_arf,
         )
     # ------------------
 
@@ -170,7 +170,7 @@ class TestARFMethods(TestARFBase):
         self.cls.wave_type = WaveTypes.STANDING
         self.assertRaises(
             NotImplementedError,
-            self.cls.acoustic_radiation_force,
+            self.cls.compute_arf,
         )
 
     def test_small_particle_limit(self) -> None:
@@ -205,7 +205,7 @@ class TestARFMethods(TestARFBase):
 
         self.assertRaises(
             ValueError,
-            self.cls.acoustic_radiation_force,
+            self.cls.compute_arf,
         )
 
     def test_arbitrary_BL_ValueError(self):
@@ -215,7 +215,7 @@ class TestARFMethods(TestARFBase):
         self.assign_parameters()
         self.assertRaises(
             NotImplementedError,
-            self.cls.acoustic_radiation_force,
+            self.cls.compute_arf,
         )
 
     def test_g1(self):
